@@ -30,12 +30,14 @@
 #include <string.h>
 
 #include "app_data.h"
-#include "search_window.h"
 #include "metadata.h"
 #include "note.h"
-#include "note_list_store.h"
+#include "conboy_note_store.h"
 #include "settings.h"
 #include "search.h"
+#include "ui_helper.h"
+#include "he-fullscreen-button.h"
+#include "search_window.h"
 
 typedef struct {
 	GtkWidget          *search_field;
@@ -53,7 +55,7 @@ is_row_visible(GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 	SearchWindowData *data = (SearchWindowData*)user_data;
 	GHashTable *search_result = data->search_result;
-	Note *note;
+	ConboyNote *note;
 
 	/* In case the search field does not exist yet, or containts no text, show all */
 	if (data->search_field == NULL) {
@@ -117,7 +119,7 @@ void on_clear_button_clicked(GtkWidget *widget, gpointer user_data)
 static
 void on_row_activated(GtkTreeView *view, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data)
 {
-	Note *note;
+	ConboyNote *note;
 	GtkTreeIter iter;
 	AppData *app_data = app_data_get();
 	GtkTreeModel *model = gtk_tree_view_get_model(view);
@@ -128,7 +130,7 @@ void on_row_activated(GtkTreeView *view, GtkTreePath *path, GtkTreeViewColumn *c
 	/* Close this window and show the selected note */
 	gtk_widget_hide(GTK_WIDGET(app_data->search_window));
 
-	note_show(note);
+	note_show(note, TRUE, TRUE, FALSE);
 }
 
 static
@@ -143,12 +145,15 @@ static gboolean
 on_delete_event(GtkWidget *window, GdkEvent *event, gpointer user_data)
 {
 	/* If no notes are open and the search window is closed, exit Conboy. */
+	gtk_widget_hide(window);
+	/*
 	AppData *app_data = app_data_get();
 	if (g_list_length(app_data->open_notes) == 0) {
 		gtk_main_quit();
 	} else {
 		gtk_widget_hide(window);
 	}
+	*/
 	return TRUE;
 }
 
@@ -156,8 +161,6 @@ static
 gboolean on_hardware_key_pressed(GtkWidget *widget, GdkEventKey	*event, gpointer user_data)
 {
 	GtkWidget *window = GTK_WIDGET(user_data);
-	AppData *app_data = app_data_get();
-	GList *open_notes;
 
 	switch (event->keyval) {
 
@@ -165,33 +168,9 @@ gboolean on_hardware_key_pressed(GtkWidget *widget, GdkEventKey	*event, gpointer
 		gtk_widget_hide(window);
 		return TRUE;
 
-	/* TODO: Duplicated code The same code (only last line differs) is used in callbacks.c */
 	case HILDON_HARDKEY_FULLSCREEN:
 		/* Toggle fullscreen */
-		app_data->fullscreen = !app_data->fullscreen;
-
-		/* Set all open windows to fullscreen or unfullscreen */
-		open_notes = app_data->open_notes;
-		while (open_notes != NULL) {
-			Note *open_note = (Note*)open_notes->data;
-			if (app_data->fullscreen) {
-				gtk_window_fullscreen(GTK_WINDOW(open_note->ui->window));
-			} else {
-				gtk_window_unfullscreen(GTK_WINDOW(open_note->ui->window));
-			}
-			open_notes = open_notes->next;
-		}
-		/* Set search window to fullscreen or unfullscreen */
-		if (app_data->search_window != NULL) {
-			if (app_data->fullscreen) {
-				gtk_window_fullscreen(GTK_WINDOW(app_data->search_window));
-			} else {
-				gtk_window_unfullscreen(GTK_WINDOW(app_data->search_window));
-			}
-		}
-
-		/* Focus again this window */
-		gtk_window_present(GTK_WINDOW(window));
+		ui_helper_toggle_fullscreen(GTK_WINDOW(window));
 		return TRUE;
 	}
 
@@ -269,12 +248,21 @@ on_scrollbar_settings_changed(GConfClient *client, guint cnxn_id, GConfEntry *en
 	}
 }
 
+/*
 static void
 on_new_note_action_activated(GtkAction *action, gpointer user_data)
 {
 	GtkWidget *window = GTK_WIDGET(user_data);
 	gtk_widget_hide(window);
-	note_show(note_create_new());
+	ConboyNote *note = conboy_note_new();
+	note_show(note, TRUE, TRUE, FALSE);
+}
+*/
+
+static void
+on_fullscreen_button_clicked (GtkAction *action, gpointer user_data)
+{
+	ui_helper_toggle_fullscreen(GTK_WINDOW(user_data));
 }
 
 static
@@ -303,8 +291,8 @@ gint compare_titles(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointe
 static
 gint compare_dates(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer user_data)
 {
-	Note *note_a;
-	Note *note_b;
+	ConboyNote *note_a, *note_b;
+	gint date_a, date_b;
 
 	if (a == NULL || b == NULL) {
 		return 0;
@@ -317,7 +305,10 @@ gint compare_dates(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer
 		return 0;
 	}
 
-	return note_a->last_change_date - note_b->last_change_date;
+	g_object_get(note_a, "change-date", &date_a, NULL);
+	g_object_get(note_b, "change-date", &date_b, NULL);
+
+	return date_a - date_b;
 }
 
 static
@@ -338,7 +329,7 @@ HildonWindow* search_window_create(SearchWindowData *window_data)
 	GtkWidget *button_sort_by_date;
 #endif
 	GtkTreeSelection *selection;
-	NoteListStore *store;
+	ConboyNoteStore *store;
 	GtkTreeModel *filtered_store;
 	GtkTreeModel *sorted_store;
 	GtkCellRenderer *renderer;
@@ -347,26 +338,43 @@ HildonWindow* search_window_create(SearchWindowData *window_data)
 	GdkScreen *screen;
 	GHashTable *search_result;
 	GtkAction *new_note_action;
+	GtkAction *fullscreen_action;
 	GtkWidget *menu_new_note;
+#ifdef HILDON_HAS_APP_MENU
+	win = hildon_stackable_window_new();
+#else
 	win = hildon_window_new();
-	gtk_window_set_title(GTK_WINDOW(win), _("Search All Notes"));
+#endif
+	gtk_window_set_title(GTK_WINDOW(win), _("Search all notes"));
 	screen = gdk_screen_get_default();
 	search_result = g_hash_table_new(NULL, NULL);
 
-	new_note_action = GTK_ACTION(gtk_action_new("new", _("New Note"), NULL, NULL));
+	GtkAccelGroup *accel_group = gtk_accel_group_new();
+	gtk_window_add_accel_group(GTK_WINDOW(win), accel_group);
+	g_object_unref(accel_group);
+
+	GtkActionGroup *action_group = gtk_action_group_new("searchwin");
+	fullscreen_action = GTK_ACTION(gtk_action_new("fullscreen", _("Fullscreen"), NULL, NULL));
+
+	gtk_action_group_add_action_with_accel(action_group, fullscreen_action, "<Ctrl>u");
+	gtk_action_set_accel_group(fullscreen_action, accel_group);
+	gtk_action_connect_accelerator(fullscreen_action);
+
 
 	/* Window menu */
 #ifdef HILDON_HAS_APP_MENU
 	menu = hildon_app_menu_new();
 
 	/* Add New Note item */
+	/*
 	menu_new_note = gtk_button_new();
 	gtk_action_connect_proxy(new_note_action, menu_new_note);
 	hildon_app_menu_append(HILDON_APP_MENU(menu), GTK_BUTTON(menu_new_note));
+	*/
 
 	/* Add sort filters */
-	button_sort_by_title = gtk_radio_button_new_with_label(NULL, _("Sort By Title"));
-	button_sort_by_date = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(button_sort_by_title), _("Sort By Date"));
+	button_sort_by_title = gtk_radio_button_new_with_label(NULL, _("Sort by title"));
+	button_sort_by_date = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(button_sort_by_title), _("Sort by date"));
 
 	/* Draw them as toggle buttons, not as radio buttons */
 	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(button_sort_by_title), FALSE);
@@ -374,15 +382,20 @@ HildonWindow* search_window_create(SearchWindowData *window_data)
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button_sort_by_date), TRUE);
 
+	gtk_widget_show(button_sort_by_title);
+	gtk_widget_show(button_sort_by_date);
+
 	hildon_app_menu_add_filter(HILDON_APP_MENU(menu), GTK_BUTTON(button_sort_by_title));
 	hildon_app_menu_add_filter(HILDON_APP_MENU(menu), GTK_BUTTON(button_sort_by_date));
 
 	hildon_window_set_app_menu(HILDON_WINDOW(win), HILDON_APP_MENU(menu));
 #else
+	/*
 	menu = gtk_menu_new();
 	menu_new_note = gtk_action_create_menu_item(new_note_action);
 	gtk_menu_shell_append(GTK_MENU_SHELL(menu), menu_new_note);
 	hildon_window_set_menu(HILDON_WINDOW(win), GTK_MENU(menu));
+	*/
 #endif
 
 	vbox = gtk_vbox_new(FALSE, 0);
@@ -485,7 +498,7 @@ HildonWindow* search_window_create(SearchWindowData *window_data)
 
 	/* CHANGE_DATE COLUMN */
 	renderer = gtk_cell_renderer_text_new();
-	change_date_column = gtk_tree_view_column_new_with_attributes(_("Last Changed"), renderer, "text", CHANGE_DATE_COLUMN, NULL);
+	change_date_column = gtk_tree_view_column_new_with_attributes(_("Last changed"), renderer, "text", CHANGE_DATE_COLUMN, NULL);
 	gtk_tree_view_column_set_sort_column_id(change_date_column, CHANGE_DATE_COLUMN);
 	gtk_tree_view_column_set_sort_indicator(change_date_column, TRUE);
 	gtk_tree_view_column_set_reorderable(change_date_column, FALSE);
@@ -513,26 +526,19 @@ HildonWindow* search_window_create(SearchWindowData *window_data)
 	g_signal_connect(win, "key_press_event", G_CALLBACK(on_hardware_key_pressed), win);
 	g_signal_connect(tree, "key_press_event", G_CALLBACK(on_key_pressed), search_field);
 	g_signal_connect(screen, "size-changed", G_CALLBACK(on_orientation_changed), window_data);
-	g_signal_connect(new_note_action, "activate", G_CALLBACK(on_new_note_action_activated), win);
+	/*g_signal_connect(new_note_action, "activate", G_CALLBACK(on_new_note_action_activated), win);*/
+	g_signal_connect(fullscreen_action, "activate", G_CALLBACK(on_fullscreen_button_clicked), win);
 
 	gconf_client_notify_add(app_data->client, SETTINGS_SCROLLBAR_SIZE, on_scrollbar_settings_changed, scrolledwindow, NULL, NULL);
 
 #ifdef HILDON_HAS_APP_MENU
 	g_signal_connect(button_sort_by_title, "toggled", G_CALLBACK(on_sort_by_title_changed), sorted_store);
 	g_signal_connect(button_sort_by_date, "toggled", G_CALLBACK(on_sort_by_date_changed), sorted_store);
-
-	/* Set initial orientation */
-	if (app_data->portrait) {
-		hildon_gtk_window_set_portrait_flags(GTK_WINDOW(win), HILDON_PORTRAIT_MODE_REQUEST);
-	} else {
-		hildon_gtk_window_set_portrait_flags(GTK_WINDOW(win), HILDON_PORTRAIT_MODE_SUPPORT);
-	}
-
+	/* Add transparent fullscreen button */
+	HeFullscreenButton *but = he_fullscreen_button_new(GTK_WINDOW(win));
+	g_signal_connect_swapped(but, "clicked", G_CALLBACK(ui_helper_toggle_fullscreen), he_fullscreen_button_get_window(but));
 #endif
 
-	app_data = app_data_get();
-	app_data->note_store = store;
-
 	return HILDON_WINDOW(win);
 }
 
@@ -544,7 +550,7 @@ void search_window_open()
 	if (app_data->search_window == NULL) {
 		window_data = g_new0(SearchWindowData, 1);
 		app_data->search_window = search_window_create(window_data);
-		hildon_program_add_window(hildon_program_get_instance(), app_data->search_window);
+		hildon_program_add_window(app_data->program, HILDON_WINDOW(app_data->search_window));
 	}
 
 	if (app_data->fullscreen) {
